==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/es-ES/admin/hardware/form.php <==
<?php

return array(
	'bulk_delete'		=> 'Confirmar eliminación masiva de bienes',
  'bulk_delete_help'	=> 'Revisar los bienes para eliminación masiva. Una vez eliminados, esos bienes pueden ser restaurados, pero no volverán a estar asociados con ningún usuario a los que esté asignado.',
  'bulk_delete_warn'	=> 'Está a punto de borrar :asset_count.',
	'bulk_update'		=> 'Actualización masiva de Equipos',
	'bulk_update_help'	=> 'Este formulario le permite actualizar múltiples Equipos simultáneamente. Solo complete los campos que quiere modificar. Todo campo en blanco permanecerá sin cambios. ',
	'bulk_update_warn'	=> 'Esta a punto de editar las propiedades de :asset_count equipos.',
    'checkedout_to'		=> 'Asignado a',
    'checkout_date'		=> 'Fecha de asignación',
    'checkin_date'		=> 'Fecha de devolución',
    'checkout_to'		=> 'Asignar a',
    'cost'				=> 'Precio Compra',
    'create'			=> 'Crear Equipo',
    'date'				=> 'Fecha Compra',
    'depreciation'	    => 'Depreciación',
    'depreciates_on'	=> 'Se deprecia en',
    'default_location'	=> 'Ubicación Predeterminada',
    'eol_date'			=> 'Fecha EOL',
    'eol_rate'			=> 'Tasa de EOL',
    'expected_checkin'  => 'Fecha Esperada de Devolución',
    'expires'			=> 'Expira',
    'fully_depreciated'	=> 'Totalmente amortizado',
    'help_checkout'		=> 'Si desea asignar este equipo inmediatamente, seleccione "Listo para Asignar" de la lista de estados de arriba. ',
    'mac_address'		=> 'MAC Dirección',
    'manufacturer'		=> 'Fabricante',
    'model'				=> 'Modelo',
    'months'			=> 'meses',
    'name'				=> 'Equipo',
    'notes'				=> 'Notas',
    'order'				=> 'Nº Pedido',
    'qr'				=> 'Código QR',
    'requestable'		=> 'Los usuarios pueden solicitarlo',
    'select_statustype'	=> 'Selecciona estado',
    'serial'			=> 'N. Serie',
    'status'			=> 'Estado',
    'tag'				=> 'Etiqueta',
    'update'			=> 'Actualizar Equipo',
    'warranty'			=> 'Garantía',
		'warranty_expires'		=> 'Vencimiento de la Garantía',
    'years'				=> 'años',
)
;

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/es-ES/admin/hardware/form.php <==
<?php

return [
    'bulk_delete'		=> 'Confirmar eliminación masiva de bienes',
  'bulk_delete_help'	=> 'Revisar los bienes para eliminación masiva. Una vez eliminados, esos bienes pueden ser restaurados, pero no volverán a estar asociados con ningún usuario a los que esté asignado.',
  'bulk_delete_warn'	=> 'Está a punto de borrar :asset_count.',
    'bulk_update'		=> 'Actualización masiva de Equipos',
    'bulk_update_help'	=> 'Este formulario le permite actualizar múltiples Equipos simultáneamente. Solo complete los campos que quiere modificar. Todo campo en blanco permanecerá sin cambios. ',
    'bulk_update_warn'	=> 'Esta a punto de editar las propiedades de :asset_count equipos.',
    'checkedout_to'		=> 'Asignado a',
    'checkout_date'		=> 'Fecha de asignación',
    'checkin_date'		=> 'Fecha de devolución',
    'checkout_to'		=> 'Asignar a',
    'cost'				=> 'Precio Compra',
    'create'			=> 'Crear Equipo',
    'date'				=> 'Fecha Compra',
    'depreciation'	    => 'Depreciación',
    'depreciates_on'	=> 'Se deprecia en',
    'default_location'	=> 'Ubicación Predeterminada',
    'eol_date'			=> 'Fecha EOL',
    'eol_rate'			=> 'Tasa de EOL',
    'expected_checkin'  => 'Fecha Esperada de Devolución',
    'expires'			=> 'Expira',
    'fully_depreciated'	=> 'Totalmente amortizado',
    'help_checkout'		=> 'Si desea asignar este equipo inmediatamente, seleccione "Listo para Asignar" de la lista de estados de arriba. ',
    'mac_address'		=> 'MAC Dirección',
    'manufacturer'		=> 'Fabricante',
    'model'				=> 'Modelo',
    'months'			=> 'meses',
    'name'				=> 'Equipo',
    'notes'				=> 'Notas',
    'order'				=> 'Nº Pedido',
    'qr'				=> 'Código QR',
    'requestable'		=> 'Los usuarios pueden solicitarlo',
    'select_statustype'	=> 'Selecciona estado',
    'serial'			=> 'N. Serie',
    'status'			=> 'Estado',
    'tag'				=> 'Etiqueta',
    'update'			=> 'Actualizar Equipo',
    'warranty'			=> 'Garantía',
        'warranty_expires'		=> 'Vencimiento de la Garantía',
    'years'				=> 'años',
    'asset_location' => 'Update Asset Location',
    'asset_location_update_default_current' => 'Update default location AND actual location',
    'asset_location_update_default' => 'Update only default location',
    'asset_not_deployable' => 'That asset status is not deployable. This asset cannot be checked out.',
    'asset_deployable' => 'That status is deployable. This asset can be checked out.',
    'processing_spinner' => 'Processing...',
];
